==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXDbusMonitor.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXDbusMonitor;no warnings;require Common::NXShellCommands;require NXDbus
;($monitoringMode_noDbus="\x5f\x5f\x6e\x6f\x44\x42\x75\x73\x5f\x5f");(
$monitoringMode_CK=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x43\x6f\x6e\x73\x6f\x6c\x65\x4b\x69\x74"
);($monitoringMode_GDM=
"\x6f\x72\x67\x2e\x67\x6e\x6f\x6d\x65\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
);($monitoringMode_FDM=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
);($monitoringMode_LOG=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x6c\x6f\x67\x69\x6e\x31"
);($event_sessionAdded="\x53\x65\x73\x73\x69\x6f\x6e\x41\x64\x64\x65\x64");(
$event_sessionRemoved="\x53\x65\x73\x73\x69\x6f\x6e\x52\x65\x6d\x6f\x76\x65\x64"
);($event_activeSessionChanged=
"\x41\x63\x74\x69\x76\x65\x53\x65\x73\x73\x69\x6f\x6e\x43\x68\x61\x6e\x67\x65\x64"
);($monitoringMode=(""));($stdout=(-(0x16e9+ 2629-0x212d)));($stdin=(-
(0x00d5+ 6494-0x1a32)));($started=(0x1a7c+ 403-0x1c0f));($pid=
(0x0a42+ 5804-0x20ee));($currentEvent=(""));sub startMonitor{if ((not (
isDbusEnabledByConfig ()))){Logger::debug (
"\x44\x42\x75\x73\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x69\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x1cc4+ 2226-0x2576));}if ($started){return ((0x0d8d+ 5465-0x22e6));}
if (($monitoringMode eq (""))){if ((not (selectMonitoringMode ()))){
Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x6e\x6f\x20\x62\x75\x73\x20\x73\x75\x69\x74\x61\x62\x6c\x65\x20\x66\x6f\x72\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x69\x6e\x67\x20\x66\x6f\x75\x6e\x64\x2e"
);return ((0x1e33+ 1696-0x24d3));}}Logger::debug (
"\x53\x74\x61\x72\x74\x69\x6e\x67\x20\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x2e"
);my ($dbusIn);my ($dbusOut);Common::NXCore::nxPipeCreateBi ((\$stdin),(\$dbusIn
));Common::NXCore::nxPipeCreateBi ((\$stdout),(\$dbusOut));if (($monitoringMode 
eq $monitoringMode_CK)){($pid=NXDbus::dbusMonitor ($dbusIn,$dbusOut,
"\x73\x79\x73\x74\x65\x6d","\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x43\x6f\x6e\x73\x6f\x6c\x65\x4b\x69\x74\x2e\x53\x65\x61\x74"
,("")));}elsif (($monitoringMode eq $monitoringMode_GDM)){($pid=
NXDbus::dbusMonitor ($dbusIn,$dbusOut,"\x73\x79\x73\x74\x65\x6d",
"\x6d\x65\x74\x68\x6f\x64\x5f\x63\x61\x6c\x6c",(""),
"\x6f\x72\x67\x2e\x67\x6e\x6f\x6d\x65\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72\x2e\x4d\x61\x6e\x61\x67\x65\x72"
,"\x52\x65\x67\x69\x73\x74\x65\x72\x53\x65\x73\x73\x69\x6f\x6e"));}elsif ((
$monitoringMode eq $monitoringMode_FDM)){($pid=NXDbus::dbusMonitor ($dbusIn,
$dbusOut,"\x73\x79\x73\x74\x65\x6d","\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
,("")));}elsif (($monitoringMode eq $monitoringMode_LOG)){($pid=
NXDbus::dbusMonitor ($dbusIn,$dbusOut,"\x73\x79\x73\x74\x65\x6d",
"\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x6c\x6f\x67\x69\x6e\x31\x2e\x4d\x61\x6e\x61\x67\x65\x72"
,("")));}if (($pid>(0x06ac+ 3636-0x14e0))){($started=(0x1539+ 869-0x189d));
Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x50\x49\x44\x20"
.$pid)."\x2e"));return ((0x18ff+ 553-0x1b27));}else{Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6e\x6f\x74\x20\x73\x74\x61\x72\x74\x65\x64\x2e"
);return ((0x19af+ 465-0x1b80));}}sub getStdout{return ($stdout);}sub isRunning{
return ($started);}sub stopMonitor{Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x74\x6f\x70\x4d\x6f\x6e\x69\x74\x6f\x72\x2e"
);if (isRunning ()){Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x65\x6e\x64\x69\x6e\x67\x20\x73\x69\x67\x74\x65\x72\x6d\x20\x74\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$pid)."\x27\x2e"));Common::NXProcess::signalProcessByRestrictedScript ($pid,
Common::NXProcess::getSignalTerm ());if ((Common::NXProcess::nxwaitpid ($pid,
$NXBits::WAIT_UNTRACED,(0x01eb+ 7819-0x2071))==$pid)){($pid=(-
(0x060c+ 2614-0x1041)));($started=(0x0702+ 1440-0x0ca2));}else{
Common::NXProcess::signalProcessByRestrictedScript ($pid,
Common::NXProcess::getSignalKill ());if ((Common::NXProcess::nxwaitpid ($pid,
$NXBits::WAIT_UNTRACED,(0x0a51+ 3883-0x1977))==$pid)){($pid=(-
(0x1371+ 4804-0x2634)));($started=(0x0352+ 5738-0x19bc));}}}}sub 
parseDbusMonitorBuffer{(my $buffer=shift (@_));(my (@lines)=split ( /\n/ ,
$buffer,(0x00b3+ 1772-0x079f)));foreach my $line (@lines){parseDbusMonitorLine (
$line);}}sub parseDbusMonitorLine{(my $line=shift (@_));Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x70\x61\x72\x73\x65\x20\x6c\x69\x6e\x65\x20\x27"
.$line)."\x27\x2e"));if (($monitoringMode eq $monitoringMode_CK)){
parseDbusMonitorLine_CK ($line);}elsif (($monitoringMode eq $monitoringMode_LOG)
){parseDbusMonitorLine_LOG ($line);}else{if (($line=~ /member=SessionRemoved/ ))
{PhysicSessions::forceCheck ();}elsif (($line=~ /member=SessionAdded/ )){
PhysicSessions::forceCheck ();}elsif (($line=~ /RegisterSession/ )){
PhysicSessions::forceCheck ();}elsif (($line=~ /object path "(.*)"/ )){(my $objectPath
=$1);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20\x27"
.$objectPath)."\x27\x2e"));}}}sub parseDbusMonitorLine_CK{(my $line=shift (@_));
if (($line=~ /member=SessionAdded/ )){PhysicSessions::forceCheck ();}elsif ((
$line=~ /member=SessionRemoved/ )){PhysicSessions::forceCheck ();}elsif (($line
=~ /member=ActiveSessionChanged/ )){PhysicSessions::forceCheck ();}elsif (($line
=~ /object path "(.*)"/ )){(my $objectPath=$1);Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($currentEvent eq $event_sessionAdded)){PhysicSessions::forceCheck
 ();}if (($currentEvent eq $event_sessionRemoved)){PhysicSessions::forceCheck ()
;}setEvent ((""));}elsif (($line=~ /string "(.*)"/ )){(my $objectPath=$1);
Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($objectPath eq (""))){setEvent ((""));return (
(0x057f+ 5020-0x191b));}if (($currentEvent eq $event_activeSessionChanged)){
PhysicSessions::forceCheck ();}setEvent ((""));}}sub parseDbusMonitorLine_LOG{(my $line
=shift (@_));if (($line=~ /member=SessionNew/ )){PhysicSessions::forceCheck ();}
elsif (($line=~ /member=SessionRemoved/ )){PhysicSessions::forceCheck ();}elsif 
(($line=~ /object path "(.*)"/ )){(my $objectPath=$1);Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($currentEvent eq $event_sessionAdded)){PhysicSessions::forceCheck
 ();}if (($currentEvent eq $event_sessionRemoved)){PhysicSessions::forceCheck ()
;}setEvent ((""));}}sub selectMonitoringMode{if (($monitoringMode ne (""))){
Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));if (($monitoringMode eq $monitoringMode_noDbus)){
return ((0x0273+ 8752-0x24a3));}return ((0x19e0+ 1302-0x1ef5));}(my (@busNames)=
NXDbus::getSystemBusNames ());foreach my $busName (@busNames){if (
canNameBeUsedToMonitor ($busName)){if (($busName eq $monitoringMode_GDM)){(
$monitoringMode=$busName);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x00d3+ 774-0x03d8));}elsif (($busName 
eq $monitoringMode_FDM)){($monitoringMode=$busName);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x0178+ 337-0x02c8));}elsif (($busName 
eq $monitoringMode_CK)){($monitoringMode=$busName);}elsif ((($busName eq 
$monitoringMode_LOG)and ($monitoringMode ne $monitoringMode_CK))){(
$monitoringMode=$busName);}elsif ((($monitoringMode ne $monitoringMode_CK)and (
$monitoringMode ne $monitoringMode_LOG))){($monitoringMode=$busName);}}}if ((
$monitoringMode ne (""))){Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x1bb5+ 786-0x1ec6));}($monitoringMode=
$monitoringMode_noDbus);return ((0x100b+ 214-0x10e1));}sub monitoringMode_byLOG{
if (($monitoringMode eq $monitoringMode_LOG)){return ((0x0436+ 5489-0x19a6));}
return ((0x02d4+ 9171-0x26a7));}sub monitoringMode_byCK{if (($monitoringMode eq 
$monitoringMode_CK)){return ((0x181d+  38-0x1842));}return ((0x19cd+ 986-0x1da7)
);}sub monitoringMode_byGDM{if (($monitoringMode eq $monitoringMode_GDM)){return
 ((0x0fb2+ 2904-0x1b09));}return ((0x1500+ 3460-0x2284));}sub 
monitoringMode_byFDM{if (($monitoringMode eq $monitoringMode_FDM)){return (
(0x00cd+ 6799-0x1b5b));}return ((0x0002+ 2051-0x0805));}sub checkByDbusDisabled{
if (($monitoringMode eq (""))){return ((0x0bad+ 1416-0x1134));}if ((
$monitoringMode eq $monitoringMode_noDbus)){return ((0x1936+ 2757-0x23fa));}
return ((0x0873+ 2351-0x11a2));}sub canNameBeUsedToMonitor{(my $name=shift (@_))
;if ((((($name eq $monitoringMode_CK)or ($name eq $monitoringMode_FDM))or ($name
 eq $monitoringMode_LOG))or ($name eq $monitoringMode_GDM))){return (
(0x0ff7+ 2843-0x1b11));}return ((0x0e46+ 1560-0x145e));}sub setEvent{(my $event=
shift (@_));($currentEvent=$event);}sub isDbusEnabledByConfig{return (
$GLOBAL::UseDbusToHandleSystemEvents);}"\x3f\x3f\x3f";

==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXDbusMonitor.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXDbusMonitor;no warnings;require Common::NXShellCommands;require NXDbus
;($monitoringMode_noDbus="\x5f\x5f\x6e\x6f\x44\x42\x75\x73\x5f\x5f");(
$monitoringMode_CK=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x43\x6f\x6e\x73\x6f\x6c\x65\x4b\x69\x74"
);($monitoringMode_GDM=
"\x6f\x72\x67\x2e\x67\x6e\x6f\x6d\x65\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
);($monitoringMode_FDM=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
);($monitoringMode_LOG=
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x6c\x6f\x67\x69\x6e\x31"
);($event_sessionAdded="\x53\x65\x73\x73\x69\x6f\x6e\x41\x64\x64\x65\x64");(
$event_sessionRemoved="\x53\x65\x73\x73\x69\x6f\x6e\x52\x65\x6d\x6f\x76\x65\x64"
);($event_activeSessionChanged=
"\x41\x63\x74\x69\x76\x65\x53\x65\x73\x73\x69\x6f\x6e\x43\x68\x61\x6e\x67\x65\x64"
);($monitoringMode=(""));($stdout=(-(0x06e7+ 423-0x088d)));($stdin=(-
(0x00f3+ 2907-0x0c4d)));($started=(0x00eb+ 6728-0x1b33));($pid=
(0x0607+ 7976-0x252f));($currentEvent=(""));sub startMonitor{if ((not (
isDbusEnabledByConfig ()))){Logger::debug (
"\x44\x42\x75\x73\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x69\x73\x20\x64\x69\x73\x61\x62\x6c\x65\x64\x2e"
);return ((0x0365+ 7453-0x2082));}if ($started){return ((0x1a80+ 824-0x1db8));}
if (($monitoringMode eq (""))){if ((not (selectMonitoringMode ()))){
Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x6e\x6f\x20\x62\x75\x73\x20\x73\x75\x69\x74\x61\x62\x6c\x65\x20\x66\x6f\x72\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x69\x6e\x67\x20\x66\x6f\x75\x6e\x64\x2e"
);return ((0x0ce9+ 3943-0x1c50));}}Logger::debug (
"\x53\x74\x61\x72\x74\x69\x6e\x67\x20\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x2e"
);my ($dbusIn);my ($dbusOut);Common::NXCore::nxPipeCreateBi ((\$stdin),(\$dbusIn
));Common::NXCore::nxPipeCreateBi ((\$stdout),(\$dbusOut));if (($monitoringMode 
eq $monitoringMode_CK)){($pid=NXDbus::dbusMonitor ($dbusIn,$dbusOut,
"\x73\x79\x73\x74\x65\x6d","\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x43\x6f\x6e\x73\x6f\x6c\x65\x4b\x69\x74\x2e\x53\x65\x61\x74"
,("")));}elsif (($monitoringMode eq $monitoringMode_GDM)){($pid=
NXDbus::dbusMonitor ($dbusIn,$dbusOut,"\x73\x79\x73\x74\x65\x6d",
"\x6d\x65\x74\x68\x6f\x64\x5f\x63\x61\x6c\x6c",(""),
"\x6f\x72\x67\x2e\x67\x6e\x6f\x6d\x65\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72\x2e\x4d\x61\x6e\x61\x67\x65\x72"
,"\x52\x65\x67\x69\x73\x74\x65\x72\x53\x65\x73\x73\x69\x6f\x6e"));}elsif ((
$monitoringMode eq $monitoringMode_FDM)){($pid=NXDbus::dbusMonitor ($dbusIn,
$dbusOut,"\x73\x79\x73\x74\x65\x6d","\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x44\x69\x73\x70\x6c\x61\x79\x4d\x61\x6e\x61\x67\x65\x72"
,("")));}elsif (($monitoringMode eq $monitoringMode_LOG)){($pid=
NXDbus::dbusMonitor ($dbusIn,$dbusOut,"\x73\x79\x73\x74\x65\x6d",
"\x73\x69\x67\x6e\x61\x6c",(""),
"\x6f\x72\x67\x2e\x66\x72\x65\x65\x64\x65\x73\x6b\x74\x6f\x70\x2e\x6c\x6f\x67\x69\x6e\x31\x2e\x4d\x61\x6e\x61\x67\x65\x72"
,("")));}if (($pid>(0x1e34+ 944-0x21e4))){($started=(0x03c3+ 7897-0x229b));
Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x50\x49\x44\x20"
.$pid)."\x2e"));return ((0x24f4+  47-0x2522));}else{Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6e\x6f\x74\x20\x73\x74\x61\x72\x74\x65\x64\x2e"
);return ((0x0dd9+ 940-0x1185));}}sub getStdout{return ($stdout);}sub isRunning{
return ($started);}sub stopMonitor{Logger::debug (
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x74\x6f\x70\x4d\x6f\x6e\x69\x74\x6f\x72\x2e"
);if (isRunning ()){Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x73\x65\x6e\x64\x69\x6e\x67\x20\x73\x69\x67\x74\x65\x72\x6d\x20\x74\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$pid)."\x27\x2e"));Common::NXProcess::signalProcessByRestrictedScript ($pid,
Common::NXProcess::getSignalTerm ());if ((Common::NXProcess::nxwaitpid ($pid,
$NXBits::WAIT_UNTRACED,(0x024f+ 5977-0x19a3))==$pid)){($pid=(-
(0x02b4+ 5036-0x165f)));($started=(0x0b9a+ 3507-0x194d));}else{
Common::NXProcess::signalProcessByRestrictedScript ($pid,
Common::NXProcess::getSignalKill ());if ((Common::NXProcess::nxwaitpid ($pid,
$NXBits::WAIT_UNTRACED,(0x01af+ 1287-0x06b1))==$pid)){($pid=(-
(0x0569+ 7201-0x2189)));($started=(0x1c16+ 1807-0x2325));}}}}sub 
parseDbusMonitorBuffer{(my $buffer=shift (@_));(my (@lines)=split ( /\n/ ,
$buffer,(0x1f9b+ 644-0x221f)));foreach my $line (@lines){parseDbusMonitorLine (
$line);}}sub parseDbusMonitorLine{(my $line=shift (@_));Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x70\x61\x72\x73\x65\x20\x6c\x69\x6e\x65\x20\x27"
.$line)."\x27\x2e"));if (($monitoringMode eq $monitoringMode_CK)){
parseDbusMonitorLine_CK ($line);}elsif (($monitoringMode eq $monitoringMode_LOG)
){parseDbusMonitorLine_LOG ($line);}else{if (($line=~ /member=SessionRemoved/ ))
{PhysicSessions::forceCheck ();}elsif (($line=~ /member=SessionAdded/ )){
PhysicSessions::forceCheck ();}elsif (($line=~ /RegisterSession/ )){
PhysicSessions::forceCheck ();}elsif (($line=~ /object path "(.*)"/ )){(my $objectPath
=$1);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20\x27"
.$objectPath)."\x27\x2e"));}}}sub parseDbusMonitorLine_CK{(my $line=shift (@_));
if (($line=~ /member=SessionAdded/ )){PhysicSessions::forceCheck ();}elsif ((
$line=~ /member=SessionRemoved/ )){PhysicSessions::forceCheck ();}elsif (($line
=~ /member=ActiveSessionChanged/ )){PhysicSessions::forceCheck ();}elsif (($line
=~ /object path "(.*)"/ )){(my $objectPath=$1);Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($currentEvent eq $event_sessionAdded)){PhysicSessions::forceCheck
 ();}if (($currentEvent eq $event_sessionRemoved)){PhysicSessions::forceCheck ()
;}setEvent ((""));}elsif (($line=~ /string "(.*)"/ )){(my $objectPath=$1);
Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($objectPath eq (""))){setEvent ((""));return (
(0x02d9+ 1742-0x09a7));}if (($currentEvent eq $event_activeSessionChanged)){
PhysicSessions::forceCheck ();}setEvent ((""));}}sub parseDbusMonitorLine_LOG{(my $line
=shift (@_));if (($line=~ /member=SessionNew/ )){PhysicSessions::forceCheck ();}
elsif (($line=~ /member=SessionRemoved/ )){PhysicSessions::forceCheck ();}elsif 
(($line=~ /object path "(.*)"/ )){(my $objectPath=$1);Logger::debug (((((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6f\x62\x6a\x65\x63\x74\x20\x70\x61\x74\x68\x20\x27"
.$objectPath)."\x27\x20\x66\x6f\x72\x20\x65\x76\x65\x6e\x74\x20").$currentEvent)
."\x2e"));if (($currentEvent eq $event_sessionAdded)){PhysicSessions::forceCheck
 ();}if (($currentEvent eq $event_sessionRemoved)){PhysicSessions::forceCheck ()
;}setEvent ((""));}}sub selectMonitoringMode{if (($monitoringMode ne (""))){
Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));if (($monitoringMode eq $monitoringMode_noDbus)){
return ((0x04f0+ 7822-0x237e));}return ((0x039b+ 4421-0x14df));}(my (@busNames)=
NXDbus::getSystemBusNames ());foreach my $busName (@busNames){if (
canNameBeUsedToMonitor ($busName)){if (($busName eq $monitoringMode_GDM)){(
$monitoringMode=$busName);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x0323+ 7404-0x200e));}elsif (($busName 
eq $monitoringMode_FDM)){($monitoringMode=$busName);Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x0206+ 8323-0x2288));}elsif (($busName 
eq $monitoringMode_CK)){($monitoringMode=$busName);}elsif ((($busName eq 
$monitoringMode_LOG)and ($monitoringMode ne $monitoringMode_CK))){(
$monitoringMode=$busName);}elsif ((($monitoringMode ne $monitoringMode_CK)and (
$monitoringMode ne $monitoringMode_LOG))){($monitoringMode=$busName);}}}if ((
$monitoringMode ne (""))){Logger::debug (((
"\x44\x42\x75\x73\x2d\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x6d\x6f\x64\x65\x20\x73\x65\x74\x20\x74\x6f\x20\x27"
.$monitoringMode)."\x27\x2e"));return ((0x1a9a+ 2628-0x24dd));}($monitoringMode=
$monitoringMode_noDbus);return ((0x00a9+ 3743-0x0f48));}sub monitoringMode_byLOG
{if (($monitoringMode eq $monitoringMode_LOG)){return ((0x1472+ 2383-0x1dc0));}
return ((0x0fbd+ 3036-0x1b99));}sub monitoringMode_byCK{if (($monitoringMode eq 
$monitoringMode_CK)){return ((0x1c96+ 629-0x1f0a));}return ((0x0999+ 450-0x0b5b)
);}sub monitoringMode_byGDM{if (($monitoringMode eq $monitoringMode_GDM)){return
 ((0x0da3+ 235-0x0e8d));}return ((0x00f3+ 9445-0x25d8));}sub 
monitoringMode_byFDM{if (($monitoringMode eq $monitoringMode_FDM)){return (
(0x13fa+ 118-0x146f));}return ((0x050d+ 5333-0x19e2));}sub checkByDbusDisabled{
if (($monitoringMode eq (""))){return ((0x0247+ 3339-0x0f51));}if ((
$monitoringMode eq $monitoringMode_noDbus)){return ((0x103a+ 4776-0x22e1));}
return ((0x0fd5+ 2899-0x1b28));}sub canNameBeUsedToMonitor{(my $name=shift (@_))
;if ((((($name eq $monitoringMode_CK)or ($name eq $monitoringMode_FDM))or ($name
 eq $monitoringMode_LOG))or ($name eq $monitoringMode_GDM))){return (
(0x0958+ 2793-0x1440));}return ((0x2184+ 278-0x229a));}sub setEvent{(my $event=
shift (@_));($currentEvent=$event);}sub isDbusEnabledByConfig{return (
$GLOBAL::UseDbusToHandleSystemEvents);}"\x3f\x3f\x3f";
